@@ -36,6 +36,8 @@ import pkg_resources
 import zc.buildout
 
 class GenericBaseRecipe(object):
+  """Boilerplate class providing helpful methods for all SlapOS recipes.
+     Can be used to extend SlapOS recipes to ease development"""
 
   TRUE_VALUES = ['y', 'yes', '1', 'true']
   FALSE_VALUES = ['n', 'no', '0', 'false']
@@ -145,9 +147,6 @@ class GenericBaseRecipe(object):
     * if the host is an ipv6 address, brackets will be added to surround it.
 
     """
-    # XXX-Antoine: I didn't find any standard module to join an url with
-    # login, password, ipv6 host and port.
-    # So instead of copy and past in every recipe I factorized it right here.
     netloc = ''
     if auth is not None:
       auth = tuple(auth)
